# Copyright (C) 2022 - 2025 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

# generated by datamodel-codegen
"""Provides the build information schema and response schemas for other data transfer operations."""

from __future__ import annotations

from typing import Any

from pydantic import BaseModel

from . import metadata, ops


class BuildInfo(BaseModel):
    """Provides the build information schema for the current build."""

    branch: str | None = None
    mode: str | None = None
    revision: str | None = None
    short_revision: str | None = None
    timestamp: str | None = None
    version: str | None = None
    version_hash: str | None = None


class CheckPermissionsResponse(BaseModel):
    """Check the permissions response schema for the current user."""

    allowed: bool | None = None


class CopyMetadataRequest(BaseModel):
    """Provides the request schema for copying metadata."""

    recursive: bool | None = None
    src_dst: list[metadata.SrcDst]


class FileDownloadTokenResponse(BaseModel):
    """Provides the token response schema for for downloading a file."""

    token: str | None = None


class GetMetadataRequest(BaseModel):
    """Provides the request schema for getting metadata."""

    paths: list[str] | None = None


class MetadataConfigResponse(BaseModel):
    """Provides the response schema for metadata configuration for the current user."""

    config: dict[str, Any] | None = None


class MoveMetadataRequest(BaseModel):
    """Provides the request schema for moving metadata."""

    recursive: bool | None = None
    src_dst: list[metadata.SrcDst]


class OpIdResponse(BaseModel):
    """Provides the response schema for an operation ID."""

    id: str | None = "2diK2kCkpgeHAQSNthIZ1JYyPte"
    location: str | None = "/api/v1/operations/2diK2kCkpgeHAQSNthIZ1JYyPte"


class OpsRequest(BaseModel):
    """Provides the request schema for operations."""

    ids: list[str]


class PermissionsConfigResponse(BaseModel):
    """Provides the response schema for permissions configuration for the current user."""

    config: dict[str, Any] | None = None


class RemoveMetadataRequest(BaseModel):
    """Provides the request schema for removing metadata."""

    paths: list[str]
    recursive: bool | None = None


class SetMetadataRequest(BaseModel):
    """Provides the request schema for setting metadata."""

    metadata: metadata.DataAssignments


class Status(BaseModel):
    """Provides the request schema for getting the build status."""

    build_info: BuildInfo | None = None
    ready: bool | None = None
    time: str | None = None


class StorageConfigResponse(BaseModel):
    """Provides the response schema for storage configuration for the current user."""

    storage: list[dict[str, Any]] | None = None


class StoragePath(BaseModel):
    """Provides the schema for a storage path with a remote."""

    path: str
    remote: str | None = "any"


class PathOperations(BaseModel):
    """Provides the schema for path operations for a list of storage paths."""

    operations: list[StoragePath]


class SrcDst(BaseModel):
    """Provides the schema for a source destination and destination storage path pair."""

    dst: StoragePath
    src: StoragePath


class SrcDstOperations(BaseModel):
    """Provides the schema for source destination operations for a list of source and destination storage path pairs."""

    operations: list[SrcDst]


class OpsResponse(BaseModel):
    """Provides the response schema for a list of operations."""

    operations: list[ops.Operation] | None = None


class CheckPermissionsRequest(BaseModel):
    """Provides the request schema for checking permissions for the current user."""

    permissions: list[perms.RoleAssignment] | None = None


class GetPermissionsRequest(BaseModel):
    """Provides the request schema for getting permissions for the current user."""

    permissions: list[perms.RoleQuery] | None = None


class GetPermissionsResponse(BaseModel):
    """Provides the response schema for getting permissions for the current user."""

    permissions: list[perms.RoleAssignment] | None = None


class RemovePermissionsRequest(BaseModel):
    """Provides the request schema for removing permissions for the current user."""

    permissions: list[perms.RoleAssignment] | None = None


class SetPermissionsRequest(BaseModel):
    """Provides the request schema for setting permissions for the current user."""

    permissions: list[perms.RoleAssignment] | None = None
