# Copyright (C) 2022 - 2025 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

# generated by datamodel-codegen
"""Provides the schemas for resource type, role type, and subject type.

Permission functionality related RoleAssignment and  RoleQuery schema.
"""

from __future__ import annotations

from enum import Enum

from pydantic import BaseModel


class ResourceType(Enum):
    """Resource type schema."""

    Doc = "document"


class RoleType(Enum):
    """Provides the role type schema for the role of the user."""

    Reader = "reader"
    Writer = "writer"
    Admin = "admin"


class SubjectType(Enum):
    """Provides the subject type schema for the user or group."""

    User = "user"
    Group = "group"
    Any = "any"


class Resource(BaseModel):
    """Provides the schema for the resource type."""

    path: str | None = "my/path/to/data/file.txt"
    type: ResourceType | None = None


class Subject(BaseModel):
    """Provides the schema for the subject type."""

    id: str | None = "946991ec-828c-4de4-acbe-962ada8bc441"
    type: SubjectType | None = None


class RoleAssignment(BaseModel):
    """Provides the schema for the role assigned to the user."""

    resource: Resource | None = None
    role: RoleType | None = None
    subject: Subject | None = None


class RoleQuery(BaseModel):
    """Provides the schema for querying the role of the user."""

    resource: Resource | None = None
    role: RoleType | None = None
    subject: Subject | None = None
